@@ -46,11 +46,12 @@ class DashboardPluginFormBase(object):
     """
     plugin_data_fields = None
 
-    def _get_plugin_data(self, fields):
+    def _get_plugin_data(self, fields, request=None):
         """
         Gets plugin data.
 
         :param iterable fields: List of tuples to iterate.
+        :param django.http.HttpRequest request:
         :return string: JSON dumpled string.
         """
         data = {}
@@ -59,15 +60,17 @@ class DashboardPluginFormBase(object):
             data.update({field: self.cleaned_data.get(field)})
         return json.dumps(data)
 
-    def get_plugin_data(self):
+    def get_plugin_data(self, request=None):
         """
         Data that would be saved in the ``plugin_data`` field of the ``dash.models.DashboardEntry``
         subclassed model.
+
+        :param django.http.HttpRequest request:
         """
         if self.plugin_data_fields:
-            return self._get_plugin_data(self.plugin_data_fields)
+            return self._get_plugin_data(self.plugin_data_fields, request=request)
 
-    def save_plugin_data(self):
+    def save_plugin_data(self, request=None):
         """
         Dummy, but necessary.
         """
@@ -990,9 +993,10 @@ class MetaBaseDashboardPluginWidget(type):
         return ' '.join(cls.html_classes)
 
 
-class classproperty(property):
+class ClassProperty(property):
     def __get__(self, cls, owner):
         return classmethod(self.fget).__get__(None, owner)()
+classproperty = ClassProperty
 
 
 class BaseDashboardPluginWidget(object):
@@ -1013,8 +1017,6 @@ class BaseDashboardPluginWidget(object):
     1, which means that a plugin occupies just 1 cell. But, certainly, there can be plugins that occupy
     more space in a placeholder.
     """
-    #__metaclass__ = MetaBaseDashboardPluginWidget
-
     layout_uid = None
     placeholder_uid = None
     plugin_uid = None
@@ -1054,6 +1056,34 @@ class BaseDashboardPluginWidget(object):
         """
         return ' '.join(cls.html_classes)
 
+    def get_width(self):
+        """
+        Gets widget width.
+
+        :return int:
+        """
+        return self.cols * self.plugin.placeholder.cell_width
+
+    def get_height(self):
+        """
+        Gets widget height.
+
+        :return int:
+        """
+        return self.rows * self.plugin.placeholder.cell_height
+
+    def get_size(self, delta_width=0, delta_height=0):
+        """
+        Gets widget size.
+        
+        :param int delta_width:
+        :param int delta_height:
+        :return tuple:
+        """
+        return (
+            (self.cols * self.plugin.placeholder.cell_width) + delta_width,
+            (self.rows * self.plugin.placeholder.cell_height) + delta_height
+        )
 
 class BaseRegistry(object):
     """
